This buys back some comment changes from Emacs,
and fixes other instances I noticed.
---
 ChangeLog                        |  6 +++---
 build-aux/announce-gen           |  4 ++--
 build-aux/prefix-gnulib-mk       |  4 ++--
 build-aux/useless-if-before-free |  4 ++--
 doc/posix-functions/utimes.texi  |  2 +-
 doc/warnings.texi                |  2 +-
 lib/c-strcaseeq.h                |  2 +-
 lib/cdefs.h                      |  2 +-
 lib/glthread/thread.c            |  2 +-
 lib/stackvma.c                   | 10 +++++-----
 lib/streq.h                      |  2 +-
 lib/thrd.c                       |  2 +-
 lib/windows-thread.c             |  2 +-
 m4/gnulib-common.m4              |  4 ++--
 m4/libgcrypt.m4                  |  2 +-
 tests/test-update-copyright.sh   |  2 +-
 16 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 211e45f8a0..50a38d675f 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -76070,7 +76070,7 @@
        localcharset, localename: MS-Windows support for non-default locales
        * lib/localcharset.c (locale_charset) [WINDOWS_NATIVE]: Before
        falling back on the default system codepage, try extracting
-       the codepage from what 'setlocale' returns.  This allows to
+       the codepage from what 'setlocale' returns.  This can
        take into account changes of the codeset due to non-default
        locale set by a previous call to 'setlocale'.
        * lib/localename.c (LOCALE_NAME_MAX_LENGTH) [WINDOWS_NATIVE]:
@@ -76078,7 +76078,7 @@
        (enum_locales_fn, get_lcid) [WINDOWS_NATIVE]: New functions.
        (gl_locale_name_thread) [WINDOWS_NATIVE]: Produce the
        current locale by calling 'setlocale', then converting the
-       locale name into LCID by calling 'get_lcid'.  This allows to
+       locale name into LCID by calling 'get_lcid'.  This can
        take into account changes in the current locale from the
        default one, in contrast to GetThreadLocale.
 
@@ -157049,7 +157049,7 @@
 
        * lib/argp-help.c (argp_doc): Split the untranslated doc string on
        '\v', and translate the two parts separately, instead of feeding
-       the whole string to gettext.  This allows to exclude
+       the whole string to gettext.  One can exclude
        '\v' from the strings visible to the translator by writing doc
        strings as N_("..") "\v" N_("..").
 
diff --git a/build-aux/announce-gen b/build-aux/announce-gen
index 8e75608cbd..3970d3ce48 100755
--- a/build-aux/announce-gen
+++ b/build-aux/announce-gen
@@ -20,7 +20,7 @@
 #
 # Written by Jim Meyering
 
-# This is a prologue that allows to run a perl script as an executable
+# This prologue allows running a perl script as an executable
 # on systems that are compliant to a POSIX version before POSIX:2017.
 # On such systems, the usual invocation of an executable through execlp()
 # or execvp() fails with ENOEXEC if it is a script that does not start
@@ -35,7 +35,7 @@
 eval 'exec perl -wSx "$0" "$@"'
      if 0;
 
-my $VERSION = '2025-01-31 23:21'; # UTC
+my $VERSION = '2025-05-08 07:37'; # UTC
 # The definition above must lie within the first 8 lines in order
 # for the Emacs time-stamp write hook (at end) to update it.
 # If you change this file with Emacs, please let the write hook
diff --git a/build-aux/prefix-gnulib-mk b/build-aux/prefix-gnulib-mk
index b287476834..b2b4867d07 100755
--- a/build-aux/prefix-gnulib-mk
+++ b/build-aux/prefix-gnulib-mk
@@ -10,7 +10,7 @@
 #
 # Written by Jim Meyering
 
-# This is a prologue that allows to run a perl script as an executable
+# This prologue allows running a perl script as an executable
 # on systems that are compliant to a POSIX version before POSIX:2017.
 # On such systems, the usual invocation of an executable through execlp()
 # or execvp() fails with ENOEXEC if it is a script that does not start
@@ -25,7 +25,7 @@
 eval 'exec perl -wSx "$0" "$@"'
      if 0;
 
-my $VERSION = '2024-07-04 10:56'; # UTC
+my $VERSION = '2025-05-08 07:38'; # UTC
 # The definition above must lie within the first 8 lines in order
 # for the Emacs time-stamp write hook (at end) to update it.
 # If you change this file with Emacs, please let the write hook
diff --git a/build-aux/useless-if-before-free b/build-aux/useless-if-before-free
index 99d474ecdf..e78fa8659f 100755
--- a/build-aux/useless-if-before-free
+++ b/build-aux/useless-if-before-free
@@ -21,7 +21,7 @@
 #
 # Written by Jim Meyering
 
-# This is a prologue that allows to run a perl script as an executable
+# This prologue allows running a perl script as an executable
 # on systems that are compliant to a POSIX version before POSIX:2017.
 # On such systems, the usual invocation of an executable through execlp()
 # or execvp() fails with ENOEXEC if it is a script that does not start
@@ -36,7 +36,7 @@
 eval 'exec perl -wSx "$0" "$@"'
      if 0;
 
-my $VERSION = '2024-07-17 02:10'; # UTC
+my $VERSION = '2025-05-08 07:38'; # UTC
 # The definition above must lie within the first 8 lines in order
 # for the Emacs time-stamp write hook (at end) to update it.
 # If you change this file with Emacs, please let the write hook
diff --git a/doc/posix-functions/utimes.texi b/doc/posix-functions/utimes.texi
index 77142dee50..3a7b3cbe97 100644
--- a/doc/posix-functions/utimes.texi
+++ b/doc/posix-functions/utimes.texi
@@ -53,5 +53,5 @@ On OS/2, this function does not work on an opened file.
 
 @mindex utimens
 Extension: Gnulib provides a module @samp{utimens} that works around these
-problems and allows to set the time with nanosecond resolution (as far as
+problems and can set the time with nanosecond resolution (as far as
 supported by the file system).
diff --git a/doc/warnings.texi b/doc/warnings.texi
index 8b1447cafe..84b7acd105 100644
--- a/doc/warnings.texi
+++ b/doc/warnings.texi
@@ -3,7 +3,7 @@
 
 @mindex warnings
 @mindex manywarnings
-The @code{warnings} module allows to regularly build a package with more
+The @code{warnings} module allows regularly building a package with more
 GCC warnings than the default warnings emitted by GCC.  It is often used
 indirectly through the @code{manywarnings} module
 (@pxref{manywarnings}).
diff --git a/lib/c-strcaseeq.h b/lib/c-strcaseeq.h
index 0eb19bcfac..4a3681007e 100644
--- a/lib/c-strcaseeq.h
+++ b/lib/c-strcaseeq.h
@@ -24,7 +24,7 @@ extern "C" {
 #endif
 
 
-/* STRCASEEQ allows to optimize string comparison with a small literal string.
+/* STRCASEEQ optimizes string comparison with a small literal string.
      STRCASEEQ (s, "UTF-8", 'U','T','F','-','8',0,0,0,0)
    is semantically equivalent to
      c_strcasecmp (s, "UTF-8") == 0
diff --git a/lib/cdefs.h b/lib/cdefs.h
index 65da09dc09..2682c092f0 100644
--- a/lib/cdefs.h
+++ b/lib/cdefs.h
@@ -497,7 +497,7 @@
 # endif
 #endif
 
-/* ISO C99 also allows to declare arrays as non-overlapping.  The syntax is
+/* ISO C99 also allows declaring arrays as non-overlapping.  The syntax is
      array_name[restrict]
    GCC 3.1 and clang support this.
    This syntax is not usable in C++ mode.  */
diff --git a/lib/glthread/thread.c b/lib/glthread/thread.c
index 82fbd263d4..2d015b6b0b 100644
--- a/lib/glthread/thread.c
+++ b/lib/glthread/thread.c
@@ -34,7 +34,7 @@ struct thrd_with_exitvalue
   void * volatile exitvalue;
 };
 
-/* The Thread-Specific Storage (TSS) key that allows to access each thread's
+/* The Thread-Specific Storage (TSS) key that allows accessing each thread's
    'struct thrd_with_exitvalue *' pointer.  */
 static tss_t thrd_with_exitvalue_key;
 
diff --git a/lib/streq.h b/lib/streq.h
index 9d91a6a610..1f1ff38f6b 100644
--- a/lib/streq.h
+++ b/lib/streq.h
@@ -26,7 +26,7 @@ extern "C" {
 #endif
 
 
-/* STREQ_OPT allows to optimize string comparison with a small literal string.
+/* STREQ_OPT optimizes string comparison with a small literal string.
      STREQ_OPT (s, "EUC-KR", 'E', 'U', 'C', '-', 'K', 'R', 0, 0, 0)
    is semantically equivalent to
      strcmp (s, "EUC-KR") == 0
diff --git a/lib/thrd.c b/lib/thrd.c
index 4a31cd868f..ea7f0f5397 100644
--- a/lib/thrd.c
+++ b/lib/thrd.c
@@ -36,7 +36,7 @@
    AIX 7.3.1 has a corrected thrd_start_t.  But the thrd_join function still
    never stores an exit code.  */
 
-/* The Thread-Specific Storage (TSS) key that allows to access each thread's
+/* The Thread-Specific Storage (TSS) key that allows accessing each thread's
    'struct thrd_with_exitcode *' pointer.  */
 static tss_t thrd_with_exitcode_key;
 
diff --git a/lib/windows-thread.c b/lib/windows-thread.c
index 2cef22f9b7..9f6fd8b606 100644
--- a/lib/windows-thread.c
+++ b/lib/windows-thread.c
@@ -29,7 +29,7 @@
 #include "windows-once.h"
 #include "windows-tls.h"
 
-/* The Thread-Local Storage (TLS) key that allows to access each thread's
+/* The Thread-Local Storage (TLS) key that allows accessing each thread's
    'struct glwthread_thread_struct *' pointer.  */
 static DWORD self_key = (DWORD)-1;
 
diff --git a/m4/gnulib-common.m4 b/m4/gnulib-common.m4
index d5bf2fb358..a07c7dd5a8 100644
--- a/m4/gnulib-common.m4
+++ b/m4/gnulib-common.m4
@@ -1630,7 +1630,7 @@ dnl
 dnl This macro sets two variables:
 dnl   - gl_cv_onwards_func_<func>   to yes / no / "future OS version"
 dnl   - ac_cv_func_<func>           to yes / no / no
-dnl The first variable allows to distinguish all three cases.
+dnl The first variable allows distinguishing all three cases.
 dnl The second variable is set, so that an invocation
 dnl   gl_CHECK_FUNCS_ANDROID([func], [[#include <foo.h>]])
 dnl can be used as a drop-in replacement for
@@ -1683,7 +1683,7 @@ dnl
 dnl This macro sets two variables:
 dnl   - gl_cv_onwards_func_<func>   to yes / no / "future OS version"
 dnl   - ac_cv_func_<func>           to yes / no / no
-dnl The first variable allows to distinguish all three cases.
+dnl The first variable allows distinguishing all three cases.
 dnl The second variable is set, so that an invocation
 dnl   gl_CHECK_FUNCS_MACOS([func], [[#include <foo.h>]])
 dnl can be used as a drop-in replacement for
diff --git a/m4/libgcrypt.m4 b/m4/libgcrypt.m4
index 353df81b6d..a891257be9 100644
--- a/m4/libgcrypt.m4
+++ b/m4/libgcrypt.m4
@@ -105,7 +105,7 @@ dnl MINIMUM-VERSION is a string with the version number 
optionally prefixed
 dnl with the API version to also check the API compatibility. Example:
 dnl a MINIMUM-VERSION of 1:1.2.5 won't pass the test unless the installed
 dnl version of libgcrypt is at least 1.2.5 *and* the API number is 1.  Using
-dnl this features allows to prevent build against newer versions of libgcrypt
+dnl this feature can prevent builds against newer versions of libgcrypt
 dnl with a changed API.
 dnl
 dnl If a prefix option is not used, the config script is first
diff --git a/tests/test-update-copyright.sh b/tests/test-update-copyright.sh
index fc405a6214..e98c541afe 100755
--- a/tests/test-update-copyright.sh
+++ b/tests/test-update-copyright.sh
@@ -34,7 +34,7 @@ s=$TMP-script
 cat <<\EOF > $s
 #!/bin/sh
 #! -*-perl-*-
-# This is a prologue that allows to run a perl script as an executable
+# This prologue allows running a perl script as an executable
 # on systems that are compliant to a POSIX version before POSIX:2017.
 # On such systems, the usual invocation of an executable through execlp()
 # or execvp() fails with ENOEXEC if it is a script that does not start
diff --git a/lib/stackvma.c b/lib/stackvma.c
index d08347fece..68ce5cae60 100644
--- a/lib/stackvma.c
+++ b/lib/stackvma.c
@@ -579,8 +579,8 @@ vma_iterate (struct callback_locals *locals)
 
 /* =========================== stackvma-mincore.c =========================== 
*/
 
-/* mincore() is a system call that allows to inquire the status of a
-   range of pages of virtual memory.  In particular, it allows to inquire
+/* mincore() is a system call that supports inquiring the status of a
+   range of pages of virtual memory.  In particular, it supports inquiring
    whether a page is mapped at all (except on Mac OS X, where mincore
    returns 0 even for unmapped addresses).
    As of 2006, mincore() is supported by:        possible bits:
@@ -593,7 +593,7 @@ vma_iterate (struct callback_locals *locals)
      - AIX,     since AIX 5.3,                   1
    As of 2019, also on
      - Hurd.
-   However, while the API allows to easily determine the bounds of mapped
+   However, while the API allows easily determining the bounds of mapped
    virtual memory, it does not make it easy to find the bounds of _unmapped_
    virtual memory ranges.  We try to work around this, but it may still be
    slow.  */
@@ -1150,8 +1150,8 @@ sigsegv_get_vma (uintptr_t address, struct vma_struct 
*vma)
 
 /* --------------------------- stackvma-mquery.c --------------------------- */
 
-/* mquery() is a system call that allows to inquire the status of a
-   range of pages of virtual memory.  In particular, it allows to inquire
+/* mquery() is a system call that supports inquiring the status of a
+   range of pages of virtual memory.  In particular, it supports inquiring
    whether a page is mapped at all, and where is the next unmapped page
    after a given address.
    As of 2021, mquery() is supported by:
-- 
2.48.1


Reply via email to